@@ -1,4 +1,4 @@
-# Copyright 2024 DARWIN EU®
+# Copyright 2025 DARWIN EU®
 #
 # This file is part of CodelistGenerator
 #
@@ -14,69 +14,49 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-#' Get descendant codes for ATC levels
+#' Get the descendant codes of Anatomical Therapeutic Chemical (ATC) classification codes
 #'
-#' @param cdm cdm_reference via CDMConnector
-#' @param level ATC level. Can be one or more of "ATC 1st", "ATC 2nd",
-#' "ATC 3rd", "ATC 4th", and "ATC 5th"
+#' @inheritParams cdmDoc
+#' @inheritParams levelATCDoc
 #' @param name ATC name of interest. For example, c("Dermatologicals",
 #' "Nervous System"), would result in a list of length two with the descendant
 #' concepts for these two particular ATC groups.
-#' @param doseForm Only descendants codes with the specified dose form
-#' will be returned. If NULL, descendant codes will be returned regardless
-#' of dose form.
-#' @param doseUnit Only descendants codes with the specified dose unit
-#' will be returned. If NULL, descendant codes will be returned regardless
-#' of dose unit
-#' @param routeCategory Only descendants codes with the specified route
-#' will be returned. If NULL, descendant codes will be returned regardless
-#' of dose form.
-#' @param type Can be "codelist", "codelist_with_details", or
-#' "concept_set_expression"
+#' @inheritParams nameStyleDoc
+#' @inheritParams doseFormDoc
+#' @inheritParams doseUnitDoc
+#' @inheritParams routeCategoryDoc
+#' @inheritParams typeNarrowDoc
 #'
-#' @return Concepts with their format based on the type argument.
+#' @return Concepts with their format based on the type argument
 #' @export
 #'
 #' @examples
 #' \donttest{
+#' library(CodelistGenerator)
 #' cdm <- mockVocabRef()
 #' getATCCodes(cdm = cdm, level = "ATC 1st")
 #' }
 getATCCodes <- function(cdm,
                         level = c("ATC 1st"),
                         name = NULL,
+                        nameStyle = "{concept_code}_{concept_name}",
                         doseForm = NULL,
                         doseUnit = NULL,
                         routeCategory = NULL,
                         type = "codelist") {
 
-
+  # initial checks
   if(type == "concept_set_expression"){
     cli::cli_abort("concept_set_expression not yet supported")
   }
-
-  errorMessage <- checkmate::makeAssertCollection()
-  checkDbType(cdm = cdm, type = "cdm_reference", messageStore = errorMessage)
-  levelCheck <- all(level %in%
-    c(
-      "ATC 1st",
-      "ATC 2nd",
-      "ATC 3rd",
-      "ATC 4th",
-      "ATC 5th"
-    ))
-  if (!isTRUE(levelCheck)) {
-    errorMessage$push(
-      "- level can only be from: ATC 1st, ATC 2nd, ATC 3rd, ATC 4th, ATC 5th"
-    )
-  }
-  checkmate::assertTRUE(levelCheck, add = errorMessage)
-  checkmate::assertVector(name,
-    add = errorMessage,
-    null.ok = TRUE
-  )
-  checkmate::assertCharacter(type, len = 1)
-  checkmate::reportAssertions(collection = errorMessage)
+  cdm <- omopgenerics::validateCdmArgument(cdm = cdm)
+  omopgenerics::assertChoice(level, c("ATC 1st", "ATC 2nd", "ATC 3rd", "ATC 4th", "ATC 5th"))
+  omopgenerics::assertCharacter(name, null = T)
+  nameStyle <- checkNameStyle(nameStyle)
+  omopgenerics::assertCharacter(doseForm, null = T)
+  omopgenerics::assertCharacter(doseUnit, null = T)
+  omopgenerics::assertCharacter(routeCategory, null = T)
+  omopgenerics::assertCharacter(type, len = 1)
 
   atc_groups <- cdm$concept |>
     dplyr::filter(.data$vocabulary_id == "ATC") |>
@@ -89,29 +69,23 @@ getATCCodes <- function(cdm,
       dplyr::filter(tidyWords(.data$concept_name) %in% tidyWords(.env$name))
   }
 
-  errorMessage <- checkmate::makeAssertCollection()
-  atcCheck <- nrow(atc_groups) > 0
-  if (!isTRUE(atcCheck)) {
-    errorMessage$push(
+  if (nrow(atc_groups) > 0) {
+    # to avoid potential memory problems will batch
+    atc_descendants <- fetchBatchedDescendants(cdm = cdm,
+                                               codes = atc_groups$concept_id,
+                                               batchSize = 500,
+                                               doseForm = doseForm)
+  }else{
+    cli::cli_abort(
       "- No matching ATC codes found"
     )
   }
-  checkmate::assertTRUE(atcCheck, add = errorMessage)
-  checkmate::reportAssertions(collection = errorMessage)
-
-  # to avoid potential memory problems will batch
-  if (nrow(atc_groups) > 0) {
-    atc_descendants <- fetchBatchedDescendants(cdm = cdm,
-                                  codes = atc_groups$concept_id,
-                                  batchSize = 500,
-                                  doseForm = doseForm)
-}
 
   if (nrow(atc_descendants) > 0) {
     atc_descendants <- atc_descendants |>
       dplyr::select("concept_id", "concept_name",
-                      "domain_id", "vocabulary_id",
-                      "ancestor_concept_id") |>
+                    "domain_id", "vocabulary_id",
+                    "ancestor_concept_id") |>
       # split different ancestors into multiple cols
       tidyr::separate_wider_delim(
         cols = "ancestor_concept_id",
@@ -123,51 +97,40 @@ getATCCodes <- function(cdm,
     atc_descendants <- atc_descendants |>
       # one row per concept + ancestor
       tidyr::pivot_longer(cols = !c("concept_id", "concept_name",
-                             "domain_id", "vocabulary_id"),
-        names_to = NULL,
-        values_to = "ancestor_concept_id",
-        values_drop_na = TRUE
+                                    "domain_id", "vocabulary_id"),
+                          names_to = NULL,
+                          values_to = "ancestor_concept_id",
+                          values_drop_na = TRUE
       )
 
-    # to list
-    # one item per concept
-    atc_descendants <- split(
-      x = atc_descendants,
-      f = as.factor(atc_descendants$ancestor_concept_id),
-      drop = TRUE
-    )
+    atc_descendants <- atc_descendants |>
+      dplyr::left_join(
+        atc_groups |>
+          dplyr::mutate("concept_name" = omopgenerics::toSnakeCase(.data$concept_name),
+                        "concept_id" = as.character(.data$concept_id)) |>
+          dplyr::mutate("name" = glue::glue(.env$nameStyle)) |>
+          dplyr::select("concept_id", "name"),
+        by = c("ancestor_concept_id" = "concept_id")
+      )
 
-    names(atc_descendants) <- dplyr::tibble(concept_id = names(atc_descendants)) |>
-      dplyr::mutate(seq = dplyr::row_number()) |>
-      dplyr::left_join(atc_groups |>
-                         dplyr::mutate(concept_id = as.character(.data$concept_id)),
-                       by= "concept_id") |>
-      dplyr::mutate(new_name = paste0(.data$concept_code, "_",
-                                      omopgenerics::toSnakeCase(.data$concept_name))) |>
-      dplyr::arrange(seq) |>
-      dplyr::pull("new_name")
-
-
-    # for each item in the list - pull out concepts and name
-    for (i in seq_along(atc_descendants)) {
-      if(type == "codelist"){
-      atc_descendants[[i]] <- atc_descendants[[i]] |>
-        dplyr::select("concept_id") |>
-        dplyr::distinct() |>
-        dplyr::pull()
-
-      } else {
-        atc_descendants[[i]] <- atc_descendants[[i]] |>
-          dplyr::select(!"ancestor_concept_id")
-      }
+    if(type == "codelist"){
+      atc_descendants <- split(
+        x = atc_descendants$concept_id,
+        f = as.factor(atc_descendants$name),
+        drop = TRUE
+      ) |>
+        omopgenerics::newCodelist()
+    }else if(type == "codelist_with_details"){
+      atc_descendants <- split(
+        x = atc_descendants,
+        f = as.factor(atc_descendants$name),
+        drop = TRUE
+      ) |>
+        purrr::map(~dplyr::select(., -"name")) |>
+        omopgenerics::newCodelistWithDetails()
     }
   }
 
-  if(type == "codelist"){
-    atc_descendants <- omopgenerics::newCodelist(atc_descendants)
-  } else {
-    atc_descendants <- omopgenerics::newCodelistWithDetails(atc_descendants)
-  }
 
   if(!is.null(routeCategory)){
     atc_descendants <- subsetOnRouteCategory(atc_descendants,
@@ -177,38 +140,26 @@ getATCCodes <- function(cdm,
 
   if(!is.null(doseUnit)){
     atc_descendants <- subsetOnDoseUnit(atc_descendants,
-                                             cdm = cdm,
-                                             doseUnit = doseUnit)
+                                        cdm = cdm,
+                                        doseUnit = doseUnit)
   }
 
   return(atc_descendants)
 }
 
-#' Get descendant codes for drug ingredients
+#' Get descendant codes of drug ingredients
 #'
-#' @param cdm cdm_reference via CDMConnector
+#' @inheritParams cdmDoc
 #' @param name Names of ingredients of interest. For example, c("acetaminophen",
 #' "codeine"), would result in a list of length two with the descendant
 #' concepts for these two particular drug ingredients. Users can also specify the
 #' concept ID instead of the name (e.g., c(1125315, 42948451)) using a numeric vector.
-#' @param nameStyle Name style to apply to returned list. Can be one of
-#' `"{concept_code}_{concept_name}"`, `"{concept_code}"`, or `"{concept_name}"`.
-#' @param doseForm Only descendants codes with the specified dose form
-#' will be returned. If NULL, descendant codes will be returned regardless
-#' of dose form.
-#' @param doseUnit Only descendants codes with the specified dose unit
-#' will be returned. If NULL, descendant codes will be returned regardless
-#' of dose unit
-#' @param routeCategory Only descendants codes with the specified route
-#' will be returned. If NULL, descendant codes will be returned regardless
-#' of route category.
-#' @param ingredientRange Used to restrict descendant codes to those
-#' associated with a specific number of ingredients. Must be a vector of length
-#' two with the first element the minimum number of ingredients allowed and
-#' the second the maximum. A value of c(2, 2) would restrict to only concepts
-#' associated with two ingredients.
-#' @param type Can be "codelist", "codelist_with_details", or
-#' "concept_set_expression"
+#' @inheritParams nameStyleDoc
+#' @inheritParams doseFormDoc
+#' @inheritParams doseUnitDoc
+#' @inheritParams routeCategoryDoc
+#' @inheritParams ingredientRangeDoc
+#' @inheritParams typeNarrowDoc
 #'
 #' @return Concepts with their format based on the type argument.
 #' @export
@@ -228,15 +179,14 @@ getDrugIngredientCodes <- function(cdm,
                                    ingredientRange = c(1, Inf),
                                    type = "codelist") {
 
+  # initial checks
   if(type == "concept_set_expression"){
     cli::cli_abort("concept_set_expression not yet supported")
   }
 
   omopgenerics::assertClass(cdm, "cdm_reference")
-  omopgenerics::assertChoice(nameStyle, choices = c("{concept_code}_{concept_name}",
-                                                    "{concept_code}",
-                                                    "{concept_name}"))
-  omopgenerics::assertChoice(type, length = 1, choices = c("codelist", "codelist_with_details", "concept_set_expression"))
+  nameStyle <- checkNameStyle(nameStyle)
+  omopgenerics::assertChoice(type, length = 1, choices = c("codelist", "codelist_with_details"))
   omopgenerics::assertNumeric(ingredientRange, length = 2, min = 0)
   omopgenerics::assertTrue(ingredientRange[1] <= ingredientRange[2])
   omopgenerics::assertCharacter(doseForm, null = TRUE)
@@ -271,89 +221,81 @@ getDrugIngredientCodes <- function(cdm,
   # to avoid potential memory problems will batch
   if (nrow(ingredientConcepts) > 0) {
     ingredientCodes <- fetchBatchedDescendants(cdm,
-      codes = ingredientConcepts$concept_id,
-      ingredientRange = ingredientRange,
-      batchSize = 500,
-      doseForm = doseForm
+                                               codes = ingredientConcepts$concept_id,
+                                               ingredientRange = ingredientRange,
+                                               batchSize = 500,
+                                               doseForm = doseForm
     )
   }
+
   if (nrow(ingredientCodes) == 0) {
     cli::cli_warn("No descendant codes found")
     return(invisible(list()))
   }
-      ingredientCodes <- ingredientCodes  |>
-        dplyr::select("concept_id", "concept_name",
-                      "domain_id", "vocabulary_id",
-                      "standard_concept",
-                      "ancestor_concept_id") |>
-      # split different ancestors into multiple cols
-      tidyr::separate_wider_delim(
-        cols = "ancestor_concept_id",
-        delim = ";",
-        names_sep = "",
-        too_few = "align_start"
-      )
 
-    ingredientCodes <- ingredientCodes |>
-      # one row per concept + ancestor
-      tidyr::pivot_longer(cols = !c("concept_id", "concept_name",
-                                    "domain_id", "vocabulary_id",
-                                    "standard_concept"),
-        names_to = NULL,
-        values_to = "ancestor_concept_id",
-        values_drop_na = TRUE
-      )
+  ingredientCodes <- ingredientCodes  |>
+    dplyr::select("concept_id", "concept_name",
+                  "domain_id", "vocabulary_id",
+                  "standard_concept",
+                  "ancestor_concept_id") |>
+    # split different ancestors into multiple cols
+    tidyr::separate_wider_delim(
+      cols = "ancestor_concept_id",
+      delim = ";",
+      names_sep = "",
+      too_few = "align_start"
+    )
 
-    # to list
-    # one item per concept
+  ingredientCodes <- ingredientCodes |>
+    # one row per concept + ancestor
+    tidyr::pivot_longer(cols = !c("concept_id", "concept_name",
+                                  "domain_id", "vocabulary_id",
+                                  "standard_concept"),
+                        names_to = NULL,
+                        values_to = "ancestor_concept_id",
+                        values_drop_na = TRUE
+    )
+
+  ingredientCodes <- ingredientCodes |>
+    dplyr::left_join(
+      ingredientConcepts |>
+        dplyr::mutate("concept_name" = omopgenerics::toSnakeCase(.data$concept_name)) |>
+        dplyr::mutate("concept_id" = as.character(.data$concept_id)) |>
+        dplyr::mutate("name" = glue::glue(.env$nameStyle)) |>
+        dplyr::select("concept_id", "name"),
+      by = c("ancestor_concept_id" = "concept_id")
+    )
+
+  if(type == "codelist"){
+    ingredientCodes <- split(
+      x = ingredientCodes$concept_id,
+      f = as.factor(ingredientCodes$name),
+      drop = TRUE
+    ) |>
+      omopgenerics::newCodelist()
+  }else if(type == "codelist_with_details"){
     ingredientCodes <- split(
       x = ingredientCodes,
-      f = as.factor(ingredientCodes$ancestor_concept_id),
+      f = as.factor(ingredientCodes$name),
       drop = TRUE
-    )
-    names(ingredientCodes) <- dplyr::tibble(concept_id = names(ingredientCodes)) |>
-    dplyr::mutate(seq = dplyr::row_number()) |>
-      dplyr::left_join(ingredientConcepts |>
-                          dplyr::mutate(concept_id = as.character(.data$concept_id)),
-                       by= "concept_id") |>
-      dplyr::mutate(concept_name = paste0(omopgenerics::toSnakeCase(.data$concept_name)),
-                    new_name = glue::glue(nameStyle)) |>
-      dplyr::arrange(seq) |>
-      dplyr::pull("new_name")
+    ) |>
+      purrr::map(~dplyr::select(., -"name")) |>
+      omopgenerics::newCodelistWithDetails()
+  }
 
-    # for each item in the list - pull out concepts and name
-    for (i in seq_along(ingredientCodes)) {
-      if(type == "codelist"){
-        ingredientCodes[[i]] <- ingredientCodes[[i]] |>
-          dplyr::select("concept_id") |>
-          dplyr::distinct() |>
-          dplyr::pull()
+  if(!is.null(routeCategory)){
+    ingredientCodes <- subsetOnRouteCategory(ingredientCodes,
+                                             cdm = cdm,
+                                             routeCategory = routeCategory)
+  }
 
-      } else {
-        ingredientCodes[[i]] <- ingredientCodes[[i]] |>
-          dplyr::select(!"ancestor_concept_id")
-      }
-    }
+  if(!is.null(doseUnit)){
+    ingredientCodes <- subsetOnDoseUnit(ingredientCodes,
+                                        cdm = cdm,
+                                        doseUnit = doseUnit)
+  }
 
-    if(type == "codelist"){
-    ingredientCodes <- omopgenerics::newCodelist(ingredientCodes)
-    } else {
-    ingredientCodes <- omopgenerics::newCodelistWithDetails(ingredientCodes)
-    }
-
-    if(!is.null(routeCategory)){
-      ingredientCodes <- subsetOnRouteCategory(ingredientCodes,
-                                               cdm = cdm,
-                                               routeCategory = routeCategory)
-    }
-
-    if(!is.null(doseUnit)){
-      ingredientCodes <- subsetOnDoseUnit(ingredientCodes,
-                                          cdm = cdm,
-                                          doseUnit = doseUnit)
-    }
-
-    return(ingredientCodes)
+  return(ingredientCodes)
 }
 
 filterIngredientConcepts <- function(ingredientConcepts, name){
